@@ -25,12 +25,19 @@
 #ifndef KWIN_WEB_H
 #define KWIN_WEB_H
 
-#include <qptrlist.h>
-#include <qbutton.h>
+#include <q3ptrlist.h>
+#include <q3button.h>
+//Added by qt3to4:
+#include <QMouseEvent>
+#include <QShowEvent>
+#include <Q3ValueList>
+#include <QResizeEvent>
+#include <QEvent>
+#include <QPaintEvent>
 
 #include <kdecoration.h>
 #include <kdecorationfactory.h>
-
+#include <kcommondecoration.h>
 class QSpacerItem;
 
 namespace OpenLook
@@ -62,7 +69,6 @@ namespace OpenLook
       QSize minimumSize() const;
       void resize( const QSize& );
       virtual void mouseDoubleClickEvent(QMouseEvent *);
-      virtual void wheelEvent(QWheelEvent *e);
 
       virtual Position mousePosition(const QPoint &) const;
       virtual bool animateMinimize(bool);
@@ -107,7 +113,7 @@ namespace OpenLook
     virtual KDecoration *createDecoration(KDecorationBridge *);
     virtual bool reset(unsigned long changed);
     virtual bool supports( Ability ability );
-    QValueList< DecorationFactory::BorderSize > borderSizes() const;
+    virtual QList< DecorationFactory::BorderSize > borderSizes() const;
   };
 }
 
